summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libsvn/svnhandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libsvn/svnhandler.cpp')
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.cpp b/kbabel/catalogmanager/libsvn/svnhandler.cpp
index bff097fd..a643f18a 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.cpp
+++ b/kbabel/catalogmanager/libsvn/svnhandler.cpp
@@ -132,12 +132,12 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
if ( !entries.exists() )
return NOT_IN_SVN;
- KProcess proc;
+ TDEProcess proc;
SVNOutputCollector out( &proc );
proc << "svn" << "status" << "-v" << "--xml" << info.absFilePath();
- if( !proc.start( KProcess::Block, KProcess::Stdout ) )
+ if( !proc.start( TDEProcess::Block, TDEProcess::Stdout ) )
return ERROR_IN_WC;
TQDomDocument doc;
@@ -290,8 +290,8 @@ void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStr
return;
}
// ### TODO: instead of making a TQString, use KProcess directly, so that it cares about quoting.
// ### TODO: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
TQString command("cd " + (templates ? _potBaseDir : _poBaseDir) + " && svn ");
switch ( cmd ) {
case SVN::Update:
@@ -503,23 +503,23 @@ bool SVNHandler::isConsideredModified( const FileStatus status ) const
return status == LOCALLY_MODIFIED || status == NOT_IN_SVN;
}
-SVNOutputCollector::SVNOutputCollector( KProcess* p )
+SVNOutputCollector::SVNOutputCollector( TDEProcess* p )
: m_process(0)
{
setProcess( p );
}
-void SVNOutputCollector::setProcess( KProcess* p )
+void SVNOutputCollector::setProcess( TDEProcess* p )
{
if( m_process )
m_process->disconnect( this );
m_process = p;
if( p ) {
- connect( p, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)),
- this, TQT_SLOT(slotGatherStdout(KProcess*, char*, int)) );
- connect( p, TQT_SIGNAL(receivedStderr(KProcess*, char*, int)),
- this, TQT_SLOT(slotGatherStderr(KProcess*, char*, int)) );
+ connect( p, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotGatherStdout(TDEProcess*, char*, int)) );
+ connect( p, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotGatherStderr(TDEProcess*, char*, int)) );
}
m_gatheredOutput.truncate( 0 );
@@ -527,13 +527,13 @@ void SVNOutputCollector::setProcess( KProcess* p )
m_stdoutOutput.truncate( 0 );
}
-void SVNOutputCollector::slotGatherStderr( KProcess*, char* data, int len )
+void SVNOutputCollector::slotGatherStderr( TDEProcess*, char* data, int len )
{
m_gatheredOutput.append( TQString::fromLocal8Bit( data, len ) );
m_stderrOutput.append( TQString::fromLocal8Bit( data, len ) );
}
-void SVNOutputCollector::slotGatherStdout( KProcess*, char* data, int len )
+void SVNOutputCollector::slotGatherStdout( TDEProcess*, char* data, int len )
{
m_gatheredOutput.append( TQString::fromLocal8Bit( data, len ) );
m_stdoutOutput.append( TQString::fromLocal8Bit( data, len ) );
@@ -290,8 +290,8 @@ void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStr
return;
}
- // ### TODO: instead of making a TQString, use KProcess directly, so that it cares about quoting.
- // ### TODO: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
+ // ### TODO: instead of making a TQString, use TDEProcess directly, so that it cares about quoting.
+ // ### TODO: use TDEProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use TDEProcess without a shell.)
TQString command("cd " + (templates ? _potBaseDir : _poBaseDir) + " && svn ");
switch ( cmd ) {